/*!
 * \file 
 * \brief Stretch Click example
 * 
 * # Description
 * The application is for stretch measuring 
 *
 * The demo application is composed of two sections :
 * 
 * ## Application Init 
 * Initialization driver enables GPIO and ADC, turn off the LED and starts write log. 
 * 
 * ## Application Task  
 * This is a example which demonstrates the use of Stretch Click board. Stretch Click reads and display ADC value.
 * 
 * \author MikroE Team
 *
 */
// ------------------------------------------------------------------- INCLUDES

#include "board.h"
#include "log.h"
#include "stretch.h"

// ------------------------------------------------------------------ VARIABLES

static stretch_t stretch;
static log_t logger;

// ------------------------------------------------------- ADDITIONAL FUNCTIONS


// ------------------------------------------------------ APPLICATION FUNCTIONS

void application_init ( void )
{
    log_cfg_t log_cfg;
    stretch_cfg_t cfg;

    //  Logger initialization.

    log_cfg.level = LOG_LEVEL_DEBUG;
    LOG_MAP_USB_UART( log_cfg );
    log_init( &logger, &log_cfg );
    log_info( &logger, "---- Application Init ----" );

    //  Click initialization.

    stretch_cfg_setup( &cfg );
    STRETCH_MAP_MIKROBUS( cfg, MIKROBUS_1 );
    stretch_init( &stretch, &cfg );

    Delay_100ms();

    log_printf( &logger, "------------------- \r\n" );
    log_printf( &logger, "  Stretch  click  "  );
    log_printf( &logger, "-------------------\r\n" );

    stretch_turn_off_led( &stretch );
    Delay_100ms( );

    log_printf( &logger, " ADC Initializated " );
    log_printf( &logger, "-------------------" );
}

void application_task ( void )
{
    stretch_data_t tmp;
    
    //  Task implementation.
    
    tmp = stretch_generic_read ( &stretch );
    log_printf( &logger, "** ADC value : [DEC]- %d, [HEX]- 0x%x \r\n", tmp, tmp );
    Delay_ms( 1000 );

    Delay_100ms( );
    
    if ( tmp < 500 )
    {
        stretch_turn_on_led( &stretch );
    }
        
    else
    {
        stretch_turn_off_led( &stretch );
    }

    log_printf( &logger, " Resistance : %d \r\n", tmp );
    log_printf( &logger, "-------------------" );
    Delay_1sec( );
}

void main ( void )
{
    application_init( );

    for ( ; ; )
    {
        application_task( );
    }
}


// ------------------------------------------------------------------------ END
